@@ -3,7 +3,7 @@ if [[ "$CONDA_BUILD" == "" ]]; then
   exit 1
 fi
 
-if [[ "$CONDA_BUILD_STATE" != "test" && "$build_platform" != "$target_platform" ]]; then
+if [[ "$CONDA_BUILD_STATE" != "TEST" && "$build_platform" != "$target_platform" ]]; then
   export R=$BUILD_PREFIX/bin/R
   export R_ARGS="--library=$PREFIX/lib/R/library --no-test-load"
   echo "R_HOME=$PREFIX/lib/R"     > $BUILD_PREFIX/lib/R/etc/Makeconf
